@@ -1,21 +1,15 @@
-"""
-Derived module from spodbase.py for classic spod.
-"""
+"""Derived module from spodbase.py for classic spod."""
 
 # import standard python packages
 import os
-import sys
 import numpy as np
 from scipy.io import loadmat
 import matplotlib as mpl
 import matplotlib.pyplot as plt
-from matplotlib import animation
-import matplotlib.gridspec as gridspec
-from matplotlib import colors as mcolors
 from mpl_toolkits.axes_grid1 import make_axes_locatable
+from matplotlib import animation
 mpl.rc('figure', max_open_warning = 0)
 from os.path import splitext
-import warnings
 
 # Current, parent and file paths
 CWD = os.getcwd()
@@ -57,7 +51,7 @@ def find_nearest_coords(coords, x, data_space_dim):
 	coords = np.asarray(coords)
 	if isinstance(x, list):
 		grid = np.array(np.meshgrid(*x))
-	elif isinstance(x,np.ndarray) == data:
+	elif isinstance(x,np.ndarray):
 		if x.shape == data_space_dim:
 			grid = x
 	else:
@@ -110,7 +104,7 @@ def get_mode_from_file(filename):
 		file at a given frequency.
 	:rtype: numpy.ndarray
 	"""
-	basename, ext = splitext(filename)
+	_, ext = splitext(filename)
 	if ext.lower() == '.npy':
 		m = np.load(filename)
 	elif ext.lower() == '.mat':
@@ -214,7 +208,6 @@ def plot_eigs_vs_frequency(eigs, freq, title='', xticks=None, yticks=None,
 		raise TypeError('`freq` must be ndarray type.')
 
 	# plot figure
-	dpi = 200
 	plt.figure(figsize=figsize, frameon=True, constrained_layout=False)
 	ax = plt.gca()
 	ratio = 1. / eigs.shape[1]
@@ -673,7 +666,6 @@ def plot_2D_mode_slice_vs_time(modes, freq_required, freq, vars_idx=[0],
 			# axis management
 			ax.set_xlim(np.nanmin(t )*1.05,np.nanmax(t )*1.05)
 			ax.set_ylim(np.nanmin(x2)*1.05,np.nanmax(x2)*1.05)
-			xlim = ax.get_xlim()
 			ax_divider = make_axes_locatable(ax)
 			cax = ax_divider.append_axes("bottom", size="5%", pad=0.65)
 			plt.colorbar(ax_obj, cax=cax, orientation="horizontal")
@@ -891,10 +883,10 @@ def plot_3D_modes_slice_at_frequency(modes, freq_required, freq, vars_idx=[0], m
 					real_ax.set_aspect('equal')
 					imag_ax.set_aspect('equal')
 				if len(title) > 1:
-	 				fig.suptitle(title + \
+					fig.suptitle(title + \
 						', mode: {}, variable ID: {}'.format(mode_id, var_id))
 				else:
-	 				fig.suptitle('mode: {}, variable ID: {}'.format(mode_id, var_id))
+					fig.suptitle('mode: {}, variable ID: {}'.format(mode_id, var_id))
 				real_ax.set_title('Real part')
 				imag_ax.set_title('Imaginary part')
 			else:
@@ -1000,7 +992,7 @@ def plot_mode_tracers(modes, freq_required, freq, coords_list, x=None, vars_idx=
 	# use the data dimensions
 	if not coords_list:
 		print('You must provide coords to `plot_mode_tracers` '
-		      'in the form list(tuple(), tuple(), ...)')
+			  'in the form list(tuple(), tuple(), ...)')
 
 	# check the coord_list is indeed list
 	if not isinstance(coords_list, list):
@@ -1017,7 +1009,6 @@ def plot_mode_tracers(modes, freq_required, freq, coords_list, x=None, vars_idx=
 
 	# get width and height figure
 	wsize = figsize[0]
-	hsize = figsize[1]
 
 	# calculate period and time vector
 	n_points = 100
@@ -1044,7 +1035,7 @@ def plot_mode_tracers(modes, freq_required, freq, coords_list, x=None, vars_idx=
 					mode = np.fft.fftshift(mode, axes=1)
 				mode_point_phase = mode[idx_coords] * phase.conj()
 				ax = fig.add_subplot(spec[cnt,0])
-				ax_obj = ax.plot(t, np.real(mode_point_phase), 'k-')
+				_ = ax.plot(t, np.real(mode_point_phase), 'k-')
 				ax.set_ylabel('mode {}'.format(mode_id),
 								rotation=0,
 								labelpad=30,
@@ -1186,7 +1177,7 @@ def plot_data_tracers(X, coords_list, x=None, time_limits=[0,10],
 	# check coord_list has correct shape and type
 	if not coords_list:
 		print('You must provide coords to `plot_mode_tracers` '
-		      'in the form list(tuple(), tuple(), ...)')
+			  'in the form list(tuple(), tuple(), ...)')
 	if not isinstance(coords_list, list):
 		raise TypeError('`coords` must be a list')
 	# get idx variables
@@ -1246,7 +1237,8 @@ def plot_data_tracers(X, coords_list, x=None, time_limits=[0,10],
 
 def generate_2D_data_video(X, time_limits=[0,10], vars_idx=None, sampling=1,
 	x1=None, x2=None, coastlines='', figsize=(12,8), path='CWD', filename='data_video.mp4'):
-	"""Make movie of 2D data.
+	"""
+		Make movie of 2D data.
 
 	:param numpy.ndarray X: 2D data to be plotted. \
 		First dimension must be time. Last dimension must be variable.
@@ -1286,10 +1278,6 @@ def generate_2D_data_video(X, time_limits=[0,10], vars_idx=None, sampling=1,
 	# filename
 	basename, ext = splitext(filename)
 
-	# figure dimensions
-	axes_ratio = (np.nanmax(x2) - np.nanmin(x2)) \
-			   / (np.nanmax(x1) - np.nanmin(x1))
-
 	# check dimension axes and data
 	if x1.shape[0] != X[0,:,:].shape[0] or \
 	   x2.shape[0] != X[0,:,:].shape[1]:
@@ -1297,10 +1285,6 @@ def generate_2D_data_video(X, time_limits=[0,10], vars_idx=None, sampling=1,
 			'Data dimension Z = (N,M); x1 and x2 '
 			'must have dimension N and M, respectively.')
 
-	# get figure size
-	wsize = figsize[0]
-	hsize = figsize[1]
-
 	# overlay coastlines if required
 	cst = False
 	if coastlines.lower() == 'regular':
@@ -1311,8 +1295,8 @@ def generate_2D_data_video(X, time_limits=[0,10], vars_idx=None, sampling=1,
 		cst = True
 
 	# Generate movie
-	vmin = np.nanmin(X)
-	vmax = np.nanmax(X)
+	#vmin = np.nanmin(X)
+	#vmax = np.nanmax(X)
 	vmean = np.nanmean(X)
 	for i in vars_idx:
 		fig = plt.figure()
@@ -1325,7 +1309,7 @@ def generate_2D_data_video(X, time_limits=[0,10], vars_idx=None, sampling=1,
 								vmin=-0.9*vmean,
 								vmax= 0.9*vmean),
 				 plt.scatter(coast['coastlon'],
-				 			 coast['coastlat'],
+							 coast['coastlat'],
 							 marker='.', c='k', s=1)]
 				for state in time_range
 			]
